@@ -6,36 +6,279 @@ LexCA <- function(object,ncp=5, context.sup="ALL", doc.sup=NULL, word.sup=NULL,
 {
 if(is.null(object)) stop("Missing argument for object")
 if (!inherits(object,"TextData")) stop("Object should be TextData class")
-
+ options(stringsAsFactors = FALSE)
+ 
+# Starting CA_New  
+ CA_New <- function (X, ncp = 5, row.sup = NULL, col.sup = NULL, quanti.sup = NULL, 
+                     quali.sup = NULL, graph = TRUE, axes = c(1, 2), row.w = NULL, 
+                     excl = NULL) 
+ {
+   
+   fct.eta2 <- function(vec, x, weights) {
+     VB <- function(xx) {
+       return(sum((colSums((tt * xx) * weights)^2)/ni))
+     }
+     tt <- tab.disjonctif(vec)
+     ni <- colSums(tt * weights)
+     unlist(lapply(as.data.frame(x), VB))/colSums(x * x *  weights)
+   }
+   
+   
+   if (is.table(X)) X <- matrix(as.vector(X), nrow(X), dimnames = dimnames(X))
+   
+   if (is.null(rownames(X))) rownames(X) <- 1:nrow(X)
+   
+   if (is.null(colnames(X))) colnames(X) <- colnames(X, do.NULL = FALSE, prefix = "V")
+   
+   X <- as.data.frame(X)
+   is.quali <- which(!unlist(lapply(X, is.numeric)))
+   
+   X[, is.quali] <- lapply(X[, is.quali, drop = FALSE], as.factor)
+   for (i in is.quali) X[, i] = as.factor(X[, i])
+   X <- droplevels(X)
+   Xtot <- X
+   
+   
+   if (any(!sapply(X, is.numeric))) {
+     auxi = NULL
+     for (j in (1:ncol(X))[!((1:ncol(X)) %in% quali.sup)]) if (!is.numeric(X[, j])) 
+       auxi = c(auxi, colnames(X)[j])
+     if (!is.null(auxi)) 
+       stop(paste("\nThe following variables are not quantitative: ", auxi))
+   }
+   if (!inherits(X, "data.frame")) stop("X is not a data.frame")
+   if (!is.null(row.sup)) X <- as.data.frame(X[-row.sup, ])
+   if ((!is.null(col.sup)) || (!is.null(quanti.sup)) || (!is.null(quali.sup))) 
+     X <- as.data.frame(X[, -c(col.sup, quanti.sup, quali.sup)])
+   
+   if (any(apply(X, 1, sum) == 0)) {
+     warning(paste0("The rows ", paste(rownames(X)[which(apply(X, 1, sum) == 0)], collapse = ", "),
+                    " sum at 0. They were suppressed from the analysis"))
+     X <- X[-which(apply(X, 1, sum) == 0), , drop = FALSE]
+   }
+   
+   
+   if (any(apply(X, 2, sum) == 0)) {
+     warning(paste0("The columns ", paste(colnames(X)[which(apply(X, 
+                                                                  2, sum) == 0)], collapse = ", "), " sum at 0. They were suppressed from the analysis"))
+     X <- X[, -which(apply(X, 2, sum) == 0), drop = FALSE]
+   }
+   
+   
+   if (is.null(row.w)) row.w = rep(1, nrow(X))
+   row.w.init <- row.w
+   
+   if (length(row.w) != nrow(X)) stop("length of vector row.w should be the number of active rows")
+   total <- sum(X * row.w)
+   
+   F <- as.matrix(X) * (row.w/total)
+   marge.col <- colSums(F)
+   marge.row <- rowSums(F)
+   ncp <- min(ncp, (nrow(X) - 1), (ncol(X) - 1))
+   Tc <- t(t(F/marge.row)/marge.col) - 1
+   if (!is.null(excl)) marge.col[excl] <- 1e-15
+   tmp <- svd.triplet(Tc, row.w = marge.row, col.w = marge.col, ncp = ncp)
+   
+   if (!is.null(excl))  marge.col[excl] <- 0
+   eig <- tmp$vs^2
+   vp <- matrix(NA, length(eig), 3)
+   rownames(vp) <- paste("dim", 1:length(eig))
+   colnames(vp) <- c("eigenvalue", "percentage of variance", 
+                     "cumulative percentage of variance")
+   vp[, "eigenvalue"] <- eig
+   vp[, "percentage of variance"] <- (eig/sum(eig)) * 100
+   vp[, "cumulative percentage of variance"] <- cumsum(vp[,"percentage of variance"])
+   V <- tmp$V
+   U <- tmp$U
+   
+   eig <- eig[1:ncol(U)]
+   coord.col <- t(t(V) * sqrt(eig))
+   coord.row <- t(t(U) * sqrt(eig))
+   dist2.col <- colSums(Tc^2 * marge.row)
+   contrib.col <- t(t(coord.col^2 * marge.col)/eig)
+   cos2.col <- coord.col^2/dist2.col
+   colnames(coord.col) <- colnames(contrib.col) <- colnames(cos2.col) <- paste("Dim",1:length(eig))
+   rownames(coord.col) <- rownames(contrib.col) <- rownames(cos2.col) <- attributes(X)$names
+   dist2.row <- rowSums(t(t(Tc^2) * marge.col))
+   contrib.row <- t(t(coord.row^2 * marge.row)/eig)
+   cos2.row <- coord.row^2/dist2.row
+   colnames(coord.row) <- colnames(contrib.row) <- colnames(cos2.row) <- paste("Dim",1:length(eig))
+   rownames(coord.row) <- rownames(contrib.row) <- rownames(cos2.row) <- attributes(X)$row.names
+   
+   
+   inertia.row = marge.row * dist2.row
+   inertia.col = marge.col * dist2.col
+   names(inertia.col) <- attributes(coord.col)$row.names
+   names(inertia.row) <- attributes(coord.row)$row.names
+   res.call <- list(X = X, marge.col = marge.col, marge.row = marge.row, 
+                    ncp = ncp, row.w = row.w, excl = excl, call = match.call(), 
+                    Xtot = Xtot, N = sum(row.w * rowSums(X)))
+   
+   res.col <- list(coord = as.matrix(coord.col[, 1:ncp]), contrib = as.matrix(contrib.col[, 1:ncp] * 100), 
+                   cos2 = as.matrix(cos2.col[, 1:ncp]), inertia = inertia.col)
+   res.row <- list(coord = coord.row[, 1:ncp], contrib = contrib.row[, 1:ncp] * 100,
+                   cos2 = cos2.row[, 1:ncp], inertia = inertia.row)
+   res <- list(eig = vp[1:min(nrow(X) - 1, ncol(X) - 1), , drop = FALSE], 
+               call = res.call, row = res.row, col = res.col, svd = tmp)
+   
+   
+   
+   
+   if (!is.null(row.sup)) {
+     X.row.sup <- as.data.frame(Xtot[row.sup, ])
+     
+     if ((!is.null(col.sup)) || (!is.null(quanti.sup)) || 
+         (!is.null(quali.sup))) 
+       X.row.sup <- as.data.frame(X.row.sup[, -c(col.sup, quanti.sup, quali.sup)])
+     somme.row <- rowSums(X.row.sup)
+     X.row.sup <- X.row.sup/somme.row
+     coord.row.sup <- crossprod(t(as.matrix(X.row.sup)), V)
+     dist2.row <- rowSums(t((t(X.row.sup) - marge.col)^2/marge.col))
+     cos2.row.sup <- coord.row.sup^2/dist2.row
+     coord.row.sup <- coord.row.sup[, 1:ncp, drop = FALSE]
+     cos2.row.sup <- cos2.row.sup[, 1:ncp, drop = FALSE]
+     colnames(coord.row.sup) <- colnames(cos2.row.sup) <- paste("Dim", 1:ncp)
+     rownames(coord.row.sup) <- rownames(cos2.row.sup) <- rownames(X.row.sup)
+     res.row.sup <- list(coord = coord.row.sup, cos2 = cos2.row.sup)
+     res$row.sup <- res.row.sup
+     res$call$row.sup <- row.sup
+   }
+   
+   if (!is.null(col.sup)) {
+     X.col.sup <- as.data.frame(Xtot[, col.sup])
+     if (!is.null(row.sup)) 
+       X.col.sup <- as.data.frame(X.col.sup[-row.sup, ])
+     X.col.sup <- X.col.sup * row.w
+     colnames(X.col.sup) <- colnames(Xtot)[col.sup]
+     somme.col <- colSums(X.col.sup)
+     X.col.sup <- t(t(X.col.sup)/somme.col)
+     coord.col.sup <- crossprod(as.matrix(X.col.sup), U)
+     dist2.col <- colSums((X.col.sup - marge.row)^2/marge.row)   
+     coord.col.sup <- as.matrix(coord.col.sup[, 1:ncp, drop = FALSE])
+     cos2.col.sup <- coord.col.sup^2/dist2.col
+     cos2.col.sup <- cos2.col.sup[, 1:ncp, drop = FALSE]
+     colnames(coord.col.sup) <- colnames(cos2.col.sup) <- paste("Dim",1:ncp)   
+     rownames(coord.col.sup) <- rownames(cos2.col.sup) <- colnames(X.col.sup)
+     res.col.sup <- list(coord = coord.col.sup, cos2 = cos2.col.sup)
+     res$col.sup <- res.col.sup
+     res$call$col.sup <- col.sup
+   }
+   
+   
+   if (!is.null(quanti.sup)) {
+     coord.quanti.sup <- matrix(NA, length(quanti.sup), ncp)
+     
+     if (is.null(row.sup)) 
+       coord.quanti.sup <- cov.wt(cbind.data.frame(res$row$coord, 
+                                                   Xtot[, quanti.sup, drop = FALSE]), cor = TRUE, 
+                                  wt = marge.row, method = "ML")$cor[-(1:ncp), 1:ncp, drop = FALSE]
+     else coord.quanti.sup <- cov.wt(cbind.data.frame(res$row$coord, 
+                                                      Xtot[-row.sup, quanti.sup, drop = FALSE]), wt = marge.row, 
+                                     cor = TRUE, method = "ML")$cor[-(1:ncp), 1:ncp, drop = FALSE]
+     dimnames(coord.quanti.sup) <- list(colnames(Xtot)[quanti.sup], paste("Dim", 1:ncp, sep = "."))   
+     res$quanti.sup$coord <- coord.quanti.sup
+     res$quanti.sup$cos2 <- coord.quanti.sup^2
+     res$call$quanti.sup <- quanti.sup
+   }
+   
+   
+   if (!is.null(quali.sup)) {
+     if (!is.null(row.sup)) 
+       X.del <- as.data.frame(Xtot[-row.sup, -c(col.sup,quanti.sup, quali.sup)])
+     else X.del <- Xtot[, -c(col.sup, quanti.sup, quali.sup)]
+     
+     X.quali.sup <- NULL
+     Xtot2 <- Xtot
+     if (!is.null(row.sup))  Xtot2 <- Xtot[-row.sup,] 
+     
+     for (j in 1:length(quali.sup)) {
+       Xtot2[,quali.sup[j]] <- droplevels(Xtot2[,quali.sup[j]] , reorder=FALSE)  
+       X.quali.sup <- rbind(X.quali.sup, matrix(unlist(by(X.del, 
+                                                          Xtot2[, quali.sup[j]], colSums)), ncol = ncol(X.del), byrow = T))
+     }
+     
+     somme.quali <- rowSums(X.quali.sup)
+     X.quali.sup <- X.quali.sup/somme.quali
+     coord.quali.sup <- crossprod(t(as.matrix(X.quali.sup)), V)
+     dist2.quali <- rowSums(t((t(X.quali.sup) - marge.col)^2/marge.col))
+     cos2.quali.sup <- coord.quali.sup^2/dist2.quali
+     coord.quali.sup <- coord.quali.sup[, 1:ncp, drop = FALSE]
+     cos2.quali.sup <- cos2.quali.sup[, 1:ncp, drop = FALSE]
+     
+     rownames(coord.quali.sup) <- rownames(cos2.quali.sup) <- paste(rep(colnames(Xtot2)[quali.sup], 
+                                                                        lapply(Xtot2[, quali.sup, drop = FALSE], nlevels)), 
+                                                                    unlist(lapply(Xtot2[, quali.sup, drop = FALSE], levels)),sep = ".") 
+     
+     colnames(coord.quali.sup) <- colnames(cos2.quali.sup) <- paste("Dim", 1:ncp)
+     res$quali.sup <- list(coord = coord.quali.sup, cos2 = cos2.quali.sup)
+     
+     Zqs <- tab.disjonctif(Xtot2[, quali.sup])
+     
+     Nj <- colSums(Zqs * row.w)
+     Nj <- colSums(Zqs * marge.row) * total
+     if (total > 1) 
+       coef <- sqrt(Nj * ((total - 1)/(total - Nj)))
+     else coef <- sqrt(Nj)
+     res$quali.sup$v.test <- res$quali.sup$coord * coef
+     
+     eta2 = matrix(NA, length(quali.sup), ncp)
+     eta2 <- sapply(as.data.frame(Xtot2[, quali.sup, drop = FALSE]), 
+                    fct.eta2, res$row$coord, weights = marge.row)
+     
+     eta2 <- t(as.matrix(eta2, ncol = ncp))
+     colnames(eta2) = paste("Dim", 1:ncp)
+     rownames(eta2) = colnames(Xtot)[quali.sup]
+     res$quali.sup$eta2 <- eta2
+     res$call$quali.sup <- quali.sup
+   }
+   class(res) <- c("CA", "list")
+   if (graph & (ncp > 1)) {
+     print(plot(res, axes = axes))
+     if (!is.null(quanti.sup)) 
+       print(plot(res, choix = "quanti.sup", axes = axes, 
+                  new.plot = TRUE))
+   }
+   return(res)
+ }
+ 
+ 
+##### Final CA_New 
+ 
 # Functions -------------------
 plotLexCA <- function()
 {
+
 # if(dev.interactive()) dev.new()
-plot.LexCA(res, selDoc=NULL, selWord=NULL, eigen=TRUE, axes=axes)
+plot.LexCA(res, selDoc=NULL, selWord=NULL, eigen=TRUE, axes=axes, graph.type = "classic", new.plot=TRUE)
 
 
 if(!is.null(res$quanti.sup$coord)) {
 #  if(dev.interactive()) dev.new()
- plot.LexCA(res, selDoc=NULL, selWord=NULL, quanti.sup=rownames(res$quanti.sup$coord), eigen=FALSE, axes=axes)
+ plot.LexCA(res, selDoc=NULL, selWord=NULL, quanti.sup=rownames(res$quanti.sup$coord), eigen=FALSE, axes=axes, graph.type = "classic",
+            new.plot=TRUE)
 }
 
 #if(dev.interactive()) dev.new()
-  plot.LexCA(res, selDoc= paste("meta ", lmd), selWord= paste("meta ", lmw), eigen=FALSE, axes=axes)
+  plot.LexCA(res, selDoc= paste("meta ", lmd), selWord= paste("meta ", lmw), eigen=FALSE, axes=axes, graph.type = "classic",
+             new.plot=TRUE)
 
 if(!is.null(rownames(res$segment$coord))& segment==TRUE){
 #  if(dev.interactive()) dev.new()
-  plot.LexCA(res, selDoc= NULL, selWord= NULL, selSeg="ALL", axes=axes)}
+  plot.LexCA(res, selDoc= NULL, selWord= NULL, selSeg="ALL", axes=axes, graph.type = "classic",
+             new.plot=TRUE)}
 
 if(!is.null(res$quali.sup)) {
 # if(dev.interactive()) dev.new()
-  plot.LexCA(res, selDoc= NULL, selWord= NULL, quali.sup="ALL", axes=axes)
+  plot.LexCA(res, selDoc= NULL, selWord= NULL, quali.sup="ALL", axes=axes, graph.type = "classic",
+             new.plot=TRUE)
  }
 
 if(!is.null(res$row.sup$coord)){
    ident <- identical(dimnames(res$quali.sup$coord)[1], dimnames(res$row.sup$coord)[1])
    if(ident==FALSE) {
 #  if(dev.interactive()) dev.new()
-   plot.LexCA(res, selDoc= NULL, selWord= NULL, selDocSup="ALL", axes=axes)
+   plot.LexCA(res, selDoc= NULL, selWord= NULL, selDocSup="ALL", axes=axes, graph.type = "classic",
+              new.plot=TRUE)
  }
 }
 
@@ -43,14 +286,12 @@ if(!is.null(res$col.sup$coord)){
    ident <- identical(dimnames(res$col.sup$coord)[1], dimnames(res$segment$coord)[1])
    if(ident==FALSE) {
 #  if(dev.interactive()) dev.new()
-   plot.LexCA(res, selDoc= NULL, selWord= NULL, selWordSup="ALL", selSeg=NULL, axes=axes)
- }
+   plot.LexCA(res, selDoc= NULL, selWord= NULL, selWordSup="ALL", selSeg=NULL, axes=axes, graph.type = "classic",
+              new.plot=TRUE) }
 }
 }
 
 
-
-
 # Put documents at the end
 remdocs <- function(z,doc_sup){
   df <- data.frame(z[,, drop=FALSE])
@@ -72,6 +313,7 @@ checkcontext <- function(context_, TDContext) {
   if(length(context_ )==0) context_ <- NULL
  return(context_) }
 
+
 # --------------- Keys function
  Keys <- function(res,lmd,lmw,naxes, axes) {			
  title <- "Metakeys & Dockeys"
@@ -89,6 +331,7 @@ if(naxes>=min(nrow(Rcontr),nrow(Ccontr)))
 Metakeys <-vector(mode="list",length=naxes)		
 for (i in 1:naxes){		
 	Metakeys[[i]]=vector(mode="list",length=2)}	
+
 for(i in 1:naxes){		
 	Metakeys[[i]][[1]]<-sort(Ccontr[which(Ccontr[,i]>lmw*mean(Ccontr[,i])&Ccoor[,i]>0),i],decreasing=TRUE)	
 	if (length(Metakeys[[i]][[1]])==1) 	
@@ -141,6 +384,8 @@ DimensionWord<-matmkeys[order(matmkeys[,1],decreasing = T),]
  ClusPal<-c(ClusPal1,ClusPal2,ClusPal3,ClusPal4)
  ClusPal<-ClusPal[!duplicated(ClusPal)]
 
+ 
+ 
  # Identify Keydocs of the dimensions "axes"
  ClusDoc1<-which(Rcontr[,axes[1]]%in%Keydocs[[axes[1]]][[1]])
  ClusDoc2<-which(Rcontr[,axes[1]]%in%Keydocs[[axes[1]]][[2]])
@@ -161,6 +406,8 @@ if(length(ClusPal)==0&length(ClusDoc)>0){
  xl=c(min(Rcoor[ClusDoc,axes[1]]),max(Rcoor[ClusDoc,axes[1]]))
  yl=c(min(Rcoor[ClusDoc,axes[2]]),max(Rcoor[ClusDoc,axes[2]]))}
 
+ 
+
 
 if(length(ClusPal)>0|length(ClusDoc)>0){
 dfW<-dfD<-NULL
@@ -193,13 +440,48 @@ keysR <- list(Word=dfW, Doc = dfD, lmd=lmd, lmw=lmw)
  cat("\nThere are no elements to plot, lower lmd and/or lmw values\n")
 }
 }
-# End Functions -------------------------
+
+ Xtab.disjonctif <- function(tab)
+ {
+   tab <- as.data.frame(tab,  stringsAsFactors = TRUE)
+   modalite.disjonctif <- function(i) {
+     moda <- as.factor(tab[, i])
+     n <- length(moda)
+     x <- matrix(0L, n, nlevels(moda))
+     x[(1:n) + n * (unclass(moda) - 1L)] <- 1L
+     return(x)
+   }
+   if (ncol(tab) == 1) {
+     res <- modalite.disjonctif(1)
+     dimnames(res) <- list(attributes(tab)$row.names, levels(tab[,1]))
+   }
+   else {
+     variable <- rep(attributes(tab)$names, lapply(tab, nlevels))
+     listModa <- unlist(lapply(tab, levels))
+     wlistModa <- which((listModa) %in% c("y", "n", 
+                                          "Y", "N"))
+     if (!is.null(wlistModa)) 
+       listModa[wlistModa] <- paste(variable[wlistModa], 
+                                    listModa[wlistModa], sep = ".")
+     numlistModa <- which(unlist(lapply(listModa, is.numeric)))
+     if (!is.null(numlistModa)) 
+       listModa[numlistModa] <- paste(variable[numlistModa], 
+                                      listModa[numlistModa], sep = ".")
+     res <- lapply(1:ncol(tab), modalite.disjonctif)
+     res <- as.matrix(data.frame(res, check.names = FALSE))
+     dimnames(res) <- list(attributes(tab)$row.names, listModa)
+   }
+   return(res)
+ }
+ 
+ 
+ # End Functions -------------------------
 
  var.text <- object$info$var.text[[1]]
  str.base <- object$info$base[[1]]
  str.envir <- object$info$menvir[[1]]
  
-
+ 
 
 info <- list(var.text= object$info$var.text, base=object$info$base,
   menvir= object$info$menvir, catquali = object$context$quali)
@@ -211,19 +493,22 @@ quali.sup <- NULL; quanti.sup<-NULL
 ndocsup <-0; nsegm <-0	
 nwordsup <- 0; nquali<-0; nquanti<-0	
 
+
+
 if(segment==TRUE)	
  if(is.null(object$DocSeg))stop("No segment selected in TextData object")
 
+
 if(var.agg=="") {
 context.quanti<-context.quali<-NULL
-if(!is.null(context)) {
 
-if(length(context)==1)
-if(context=="ALL") {
+if(!is.null(context)) {
+ if(length(context)==1)
+  if(context=="ALL") {
   context<- NULL
  if(!is.null(object$context$quali)) context <- as.character(colnames(object$context$quali))
  if(!is.null(object$context$quanti)) context <- c(context,colnames(object$context$quanti))
-}
+   }
   if(!is.null(object$context$quanti)){
    context.quanti <- checkcontext(context,object$context$quanti)
    context.quanti <- colnames(object$context$quanti)[context.quanti]
@@ -242,13 +527,15 @@ if(context=="ALL") {
    context.quali <- colnames(object$context$quali)[context.quali]
 
    if(length(context.quali)==0) context.quali<-NULL
+
 } else { context.quali<- NULL}
 } # Final if(!is.null(context))
 
 
+
 # ========== Check quali variables $context$quali no aggregate
 if(!is.null(context.quali))	
-object$context$quali <- data.frame(object$context$quali[,context.quali,drop=FALSE])	
+object$context$quali <- data.frame(object$context$quali[,context.quali,drop=FALSE] )
 
 # =======  Check quanti variables $context$quanti no aggregate
 if(!is.null(context.quanti)) 	
@@ -263,31 +550,33 @@ if(segment==TRUE){  LTS <- as.matrix(object$DocSeg)
 if(!is.null(doc.sup)) {	
       if (is.character(doc.sup)) 	
          doc.sup <- which(rownames(LT) %in% doc.sup)	
-         doc.sup <- rownames(LT)[doc.sup]	
+         doc.sup <- rownames(LT)[doc.sup]	 
          doc.sup <- doc.sup[!is.na(doc.sup)]	
          doc.sup <- which(rownames(LT)%in% doc.sup)	
- ndocsup <- length(doc.sup)	
+         ndocsup <- length(doc.sup)	
  if(ndocsup==0) doc.sup <- NULL	
 }	
 ndocact <- ndoc - ndocsup
 
+
 # Put supplementary docs at the end	
 if(ndocsup>0) {	
   tmpdf <- LT[doc.sup,,drop=FALSE]
   LT <- LT[-doc.sup,,drop=FALSE] 
   LT <- rbind(LT,tmpdf)
-
  if(!is.null(context.quali)) if(length(context.quali)>0)  	
      object$context$quali<- remdocs(object$context$quali,doc.sup)	
  if(!is.null(context.quanti)) if(length(context.quanti)>0)	
   object$context$quanti<- remdocs(object$context$quanti,doc.sup)
-#_____________________________________________
+
+  #_____________________________________________
 if(segment==TRUE){	
  tmpdf <- LTS[doc.sup,,drop=FALSE]
   LTS <- LTS[-doc.sup,,drop=FALSE] 
   LTS <- rbind(LTS,tmpdf)
 }} # final de if(!is.null(doc.sup))	
 
+
 #_____________________________________________	
 nword <- ncol(LT)
 nwordact <- nword
@@ -296,14 +585,16 @@ if(!is.null(word.sup)) {
       if (!is.character(word.sup)) 					
       word.sup <- colnames(LT)[word.sup]
       word.sup <- which(colnames(LT) %in% word.sup)	
-    nwordsup <- length(word.sup)
- if(nwordsup==0){ word.sup <- NULL} else {
+      nwordsup <- length(word.sup)
+
+   if(nwordsup==0){ word.sup <- NULL} else {
     LT <- cbind(LT,LT[,word.sup])	
     wcolnames <- colnames(LT)[word.sup]
      LT <- LT[,-word.sup]	
    colnames(LT)[(ncol(LT)-nwordsup+1):ncol(LT)] <- wcolnames
    nwordact <- ncol(LT) - nwordsup}	}
 
+
 #_____________________________________________	
 # Remove supplementary words with zero sum	
 if(!is.null(word.sup)) if(nwordsup>0) {
@@ -330,6 +621,7 @@ pos.elim<-which(colSums(LTS[c(1:ndocact),,drop=FALSE])==0)
   nsegm <- ncol(LTS)	
    LT <- cbind(LT,LTS)	}	
 
+  
 # ==== Yuxtapostition of qualitative and quantitative variables 	
  if(length(context.quali)>0) {
       yQL <- data.frame(object$context$quali[rownames(LT),context.quali])
@@ -342,6 +634,7 @@ pos.elim<-which(colSums(LTS[c(1:ndocact),,drop=FALSE])==0)
 	LT <- cbind(LT,yQ)
       nquanti <- ncol(yQ)}	
 
+  
 #_____________________________________________
 # ==== Remove supplementary empty docs 
 if(ndocsup>0) {
@@ -351,6 +644,7 @@ pos.elim<-which(rowSums(LT[c((ndocact+1):ndoc),c(1:nwordact),drop=FALSE])==0)
   ndocsup <- ndocsup - length(pos.elim)
 }}
 
+
 #_____________________________________________
 # ==== Remove empty docs 
   pos.elim<-which(rowSums(LT[c(1:nrow(LT)),c(1:nwordact),drop=FALSE])==0)
@@ -359,6 +653,10 @@ if(length(pos.elim)>0)
  ndoc <- nrow(LT)
  ndocact <- ndoc-ndocsup
 
+ 
+
+ 
+ 
 #_____________________________________________
 # Fill NA quantitative values with the average
 if(nquanti >0){
@@ -368,6 +666,7 @@ if(any(is.na(LT[,i]))) warning("\n", names(LT)[i], " variable has missing values
   LT[is.na(LT[,i]), i] <- mean(LT[,i], na.rm = TRUE)
 }}
 
+
 if(ndocact <3)
     stop("At least three active documents have to be selected")
 if(nwordact <3)
@@ -375,25 +674,33 @@ if(nwordact <3)
 minrowcol <- min((ndocact-1), (nwordact-1))
 ncp <- min(ncp, minrowcol)
 
-if(ndocsup >0){ row.sup <- c(c(ndocact+1):ndoc)} else {row.sup <-NULL}
-word.sup <-NULL
-ncoltemp <- nwordact
-if(nwordsup >0){ word.sup <- c((nwordact+1):(nwordact+nwordsup)); ncoltemp <- ncoltemp+nwordsup}
-if(nsegm >0){ word.supseg <- c(c(c(ncoltemp+1):c(ncoltemp+nsegm))); ncoltemp <- ncoltemp+nsegm
 
-word.sup <- c(word.sup,word.supseg) }
+if(ndocsup >0){ row.sup <- c(c(ndocact+1):ndoc)} else {row.sup <-NULL}
+
+pos.word.sup <- pos.seg.sup <- NULL
+ncoltemp <- nwordact
+if(nwordsup >0){ 
+  pos.word.sup <- c((ncoltemp +1):(ncoltemp+nwordsup))   
+  ncoltemp <- ncoltemp + nwordsup
+}
+
+if(nsegm >0){
+  pos.seg.sup <- c(c(ncoltemp +1):c(ncoltemp+nsegm))       # 1081 al 2713  ; Hay 1487 segmentos
+  ncoltemp <- ncoltemp + nsegm
+}
+pos.col.sup <- c(pos.word.sup,pos.seg.sup)
+
+
 if(nquali >0){ quali.sup <- c((ncoltemp+1):(ncoltemp+nquali)); ncoltemp <- ncoltemp+nquali}
 if(nquanti >0){ quanti.sup <- c((ncoltemp+1):(ncoltemp+nquanti)); ncoltemp <- ncoltemp+nquanti}
 
+# res <- FactoMineR::CA(LT, ncp, row.sup=row.sup, col.sup=word.seg.sup, quali.sup=quali.sup, quanti.sup=quanti.sup, graph=FALSE)
+# res <- FactoMineR::CA(LT, ncp, row.sup=row.sup, col.sup=pos.col.sup, quali.sup=quali.sup, quanti.sup=quanti.sup, graph=FALSE)
+res <- CA_New(LT, ncp, row.sup=row.sup, col.sup=pos.col.sup, quali.sup=quali.sup, quanti.sup=quanti.sup, graph=FALSE)
+res$meta <- Keys(res,lmd,lmw,naxes, axes)
 
 
 
-
-
-
-
-res <- CA(LT, ncp, row.sup=row.sup, col.sup=word.sup, quali.sup=quali.sup, quanti.sup=quanti.sup, graph=FALSE)
- res$meta <- Keys(res,lmd,lmw,naxes, axes)
 #################################
 ############ Modificada la siguiente:
 ##### res$VCr <- round(sqrt(sum(res$eig[, 1])/ (minrowcol-1) ), 4)
@@ -401,26 +708,37 @@ res <- CA(LT, ncp, row.sup=row.sup, col.sup=word.sup, quali.sup=quali.sup, quant
  res$Inertia <- round(sum(res$eig[, 1]), 4)
  res$info <- info
 
-if(segment==TRUE) if(ncol(LTS)==0) segment<-NULL
-if(segment==TRUE) {
- nsegm <- ncol(LTS)	
+ 
+ if(segment==TRUE) if(ncol(LTS)==0) segment<-NULL
+ 
+ if(segment==TRUE) {
+  nsegm <- ncol(LTS)	
+
  if(nwordsup>0){
  res$segment <- res$col.sup
  res$segment$coord <- res$segment$coord[-c(1:nwordsup),,drop=FALSE]
  res$segment$cos2 <- res$segment$cos2[-c(1:nwordsup),,drop=FALSE]
+ res$col.sup$coord <- res$col.sup$coord[c(1:nwordsup),,drop=FALSE]
+ res$col.sup$cos2 <- res$col.sup$cos2[c(1:nwordsup),,drop=FALSE] 
 } else {
  res$segment <- ""
  suppressWarnings(res$segment$coord <-res$col.sup$coord[(1:nsegm),,drop=FALSE]) 
  suppressWarnings(res$segment$cos2 <- res$col.sup$cos2[(1:nsegm),,drop=FALSE])
-}}
+}
+  }
 
 
 if(!is.null(res$quali.sup$coord)) {
   res$quali.sup$cos2 <- res$quali.sup$coord[,,drop=FALSE]
-  Xact <- as.matrix( LT[,1:nwordact, drop=FALSE])
-  PJ <- colSums(Xact)/sum(Xact)
-  tt <-as.matrix( t(tab.disjonctif(as.matrix(LT[,quali.sup,drop=FALSE]))))
-  PIJ <- tt %*% (Xact/sum(Xact))
+  if(is.null(row.sup))
+    LTnosup <- LT
+  else LTnosup <- LT[-row.sup,, drop=FALSE]
+
+  
+   Xact <- as.matrix(LTnosup[,1:nwordact, drop=FALSE]) 
+   PJ <- colSums(Xact)/sum(Xact)
+   tt <-as.matrix( t(Xtab.disjonctif(as.matrix(LTnosup[,quali.sup,drop=FALSE]))))
+   PIJ <- tt %*% (Xact/sum(Xact))
   disto2 <- ((t(PIJ/rowSums(PIJ)) -PJ)^2)/PJ
   disto2 <- colSums(disto2)
   cos2 <- res$quali.sup$coord^2 
@@ -429,10 +747,15 @@ if(!is.null(res$quali.sup$coord)) {
 
 res$rowINIT <- object$rowINIT 
  class(res) <- c("LexCA","CA", "list")
-
+ 
 if(graph==TRUE) plotLexCA()
 return(res)
-} else {
+
+ 
+ 
+ 
+ 
+ } else {
 
 
 ## Aggregate analysis
@@ -525,8 +848,11 @@ if(!is.null(context.quali))
    LTQL <- data.frame(object$context$quali$qualitable[,,drop=FALSE])
 
 nwordact <- ncol(LT); nword<- nwordact	
-# Put supplementary words at the right word.sup	
 
+
+
+#==================================================================
+# Put supplementary words at the right word.sup	
 if(!is.null(word.sup)) {	
    if (!is.character(word.sup)) 					
     word.sup <- colnames(LT)[word.sup]
@@ -627,7 +953,7 @@ if(nquanti >0){
 
 
 if((ndocsup+nquali)>0) doc.sup <- c((ndocact+1):(ndocact+ndocsup+nquali))
-res <- CA(LT, ncp, row.sup=doc.sup, col.sup=word.sup, quanti.sup=quanti.sup.q, graph=FALSE)
+res <- CA_New(LT, ncp, row.sup=doc.sup, col.sup=word.sup, quanti.sup=quanti.sup.q, graph=FALSE)
 res$var.agg <- var.agg
 res$meta <- Keys(res,lmd,lmw,naxes, axes)
 ####### Modificar lo siguiente
